using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using DotNetNuke;
using DotNetNuke.Common.Utilities;
using DotNetNuke.Entities.Modules;
using DotNetNuke.Services.Search;

namespace YourCompany.DNNConnect.Components
{
    public class DNNConnectController : ISearchable, IPortable
    {

        #region public method

        /// <summary>
        /// Gets all the DNNConnectInfo objects for items matching the this moduleId
        /// </summary>
        /// <param name="moduleId"></param>
        /// <returns></returns>
        public List<DNNConnectInfo> GetDNNConnects(int moduleId)
        {
            return CBO.FillCollection<DNNConnectInfo>(DataProvider.Instance().GetDNNConnects(moduleId));
        }

        /// <summary>
        /// Get an info object from the database
        /// </summary>
        /// <param name="moduleId"></param>
        /// <param name="itemId"></param>
        /// <returns></returns>
        public DNNConnectInfo GetDNNConnect(int moduleId, int itemId)
        {
            return (DNNConnectInfo)CBO.FillObject(DataProvider.Instance().GetDNNConnect(moduleId, itemId), typeof(DNNConnectInfo));
        }


        /// <summary>
        /// Adds a new DNNConnectInfo object into the database
        /// </summary>
        /// <param name="info"></param>
        public void AddDNNConnect(DNNConnectInfo info)
        {
            //check we have some content to store
            if (info.Content != string.Empty)
            {
                DataProvider.Instance().AddDNNConnect(info.ModuleId, info.Content, info.CreatedByUser);
            }
        }

        /// <summary>
        /// update a info object already stored in the database
        /// </summary>
        /// <param name="info"></param>
        public void UpdateDNNConnect(DNNConnectInfo info)
        {
            //check we have some content to update
            if (info.Content != string.Empty)
            {
                DataProvider.Instance().UpdateDNNConnect(info.ModuleId, info.ItemId, info.Content, info.CreatedByUser);
            }
        }


        /// <summary>
        /// Delete a given item from the database
        /// </summary>
        /// <param name="moduleId"></param>
        /// <param name="itemId"></param>
        public void DeleteDNNConnect(int moduleId, int itemId)
        {
            DataProvider.Instance().DeleteDNNConnect(moduleId, itemId);
        }


        #endregion

        #region ISearchable Members

        /// <summary>
        /// Implements the search interface required to allow DNN to index/search the content of your
        /// module
        /// </summary>
        /// <param name="modInfo"></param>
        /// <returns></returns>
        public DotNetNuke.Services.Search.SearchItemInfoCollection GetSearchItems(ModuleInfo modInfo)
        {
            SearchItemInfoCollection searchItems = new SearchItemInfoCollection();

            List<DNNConnectInfo> infos = GetDNNConnects(modInfo.ModuleID);

            foreach (DNNConnectInfo info in infos)
            {
                SearchItemInfo searchInfo = new SearchItemInfo(modInfo.ModuleTitle, info.Content, info.CreatedByUser, info.CreatedDate,
                                                    modInfo.ModuleID, info.ItemId.ToString(), info.Content, "Item=" + info.ItemId.ToString());
                searchItems.Add(searchInfo);
            }

            return searchItems;
        }

        #endregion

        #region IPortable Members

        /// <summary>
        /// Exports a module to xml
        /// </summary>
        /// <param name="ModuleID"></param>
        /// <returns></returns>
        public string ExportModule(int moduleID)
        {
            StringBuilder sb = new StringBuilder();

            List<DNNConnectInfo> infos = GetDNNConnects(moduleID);

            if (infos.Count > 0)
            {
                sb.Append("<DNNConnects>");
                foreach (DNNConnectInfo info in infos)
                {
                    sb.Append("<DNNConnect>");
                    sb.Append("<content>");
                    sb.Append(XmlUtils.XMLEncode(info.Content));
                    sb.Append("</content>");
                    sb.Append("</DNNConnect>");
                }
                sb.Append("</DNNConnects>");
            }

            return sb.ToString();
        }

        /// <summary>
        /// imports a module from an xml file
        /// </summary>
        /// <param name="ModuleID"></param>
        /// <param name="Content"></param>
        /// <param name="Version"></param>
        /// <param name="UserID"></param>
        public void ImportModule(int ModuleID, string Content, string Version, int UserID)
        {
            XmlNode infos = DotNetNuke.Common.Globals.GetContent(Content, "DNNConnects");

            foreach (XmlNode info in infos.SelectNodes("DNNConnect"))
            {
                DNNConnectInfo DNNConnectInfo = new DNNConnectInfo();
                DNNConnectInfo.ModuleId = ModuleID;
                DNNConnectInfo.Content = info.SelectSingleNode("content").InnerText;
                DNNConnectInfo.CreatedByUser = UserID;

                AddDNNConnect(DNNConnectInfo);
            }
        }

        #endregion
    }
}
